@@ -1,3 +1,4 @@
+
 package Sys::Load;
 
 use 5.006;
@@ -9,32 +10,45 @@ require DynaLoader;
 
 our @ISA = qw(Exporter DynaLoader);
 
-our @EXPORT_OK = qw( getload );
+our @EXPORT_OK = qw( getload uptime );
 
-our $VERSION = '0.1';
+our $VERSION = '0.2';
 
 bootstrap Sys::Load $VERSION;
 
 # Preloaded methods go here.
 
+use constant UPTIME => "/proc/uptime";
+
+sub uptime {
+  open(FILE, UPTIME) || return 0;
+  my $line = <FILE>;
+  my($uptime, $idle) = split /\s+/, $line;
+  close FILE;
+  return $uptime;
+}
+
 1;
+
 __END__
 
 =head1 NAME
 
-Sys::Load - Perl module for getting the current system load
+Sys::Load - Perl module for getting the current system load and uptime
 
 =head1 SYNOPSIS
 
-  use Sys::Load qw/getload/;
-  my @load = getload();
-  print "System load: ", $load[0], "\n";
+  use Sys::Load qw/getload uptime/;
+  print "System load: ", (getload())[0], "\n";
+  print "System uptime: ", int uptime(), "\n";
 
 =head1 DESCRIPTION
 
 getload() returns 3 elements: representing load averages over the last 1, 5 and
 15 minutes. On failure empty list is returned.
 
+uptime() returns the system uptime in seconds. Returns 0 on failure.
+
 =head2 EXPORT
 
 None by default.
@@ -45,7 +59,7 @@ Peter BARABAS, E<lt>z0d [@] artifact [.] huE<gt>
 
 =head1 SEE ALSO
 
-L<getloadavg(3)>
+L<getloadavg(3)>, L<uptime(1)>
 
 =cut
 
